.. -*- coding: utf-8 -*-

URL Rewriting (:mod:`cubicweb.web.views.urlpublish`) and (:mod:`cubicweb.web.views.urlrewrite`)
------------------------------------------------------------------------------------------------

XXX feed me
show how urls are mapped to selections and views and explain URLRewriting
